@@ -18,10 +18,10 @@
  * along with this library; if not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __GSPELL_CHECKER_DIALOG_H__
-#define __GSPELL_CHECKER_DIALOG_H__
+#ifndef GSPELL_CHECKER_DIALOG_H
+#define GSPELL_CHECKER_DIALOG_H
 
-#if !defined (__GSPELL_H_INSIDE__) && !defined (GSPELL_COMPILATION)
+#if !defined (GSPELL_H_INSIDE) && !defined (GSPELL_COMPILATION)
 #error "Only <gspell/gspell.h> can be included directly."
 #endif
 
@@ -31,6 +31,8 @@
 G_BEGIN_DECLS
 
 #define GSPELL_TYPE_CHECKER_DIALOG (gspell_checker_dialog_get_type ())
+
+G_MODULE_EXPORT
 G_DECLARE_DERIVABLE_TYPE (GspellCheckerDialog, gspell_checker_dialog,
 			  GSPELL, CHECKER_DIALOG,
 			  GtkDialog)
@@ -43,13 +45,13 @@ struct _GspellCheckerDialogClass
 	gpointer padding[8];
 };
 
+G_MODULE_EXPORT
 GtkWidget *		gspell_checker_dialog_new			(GtkWindow       *parent,
 									 GspellNavigator *navigator);
 
+G_MODULE_EXPORT
 GspellNavigator *	gspell_checker_dialog_get_spell_navigator	(GspellCheckerDialog *dialog);
 
 G_END_DECLS
 
-#endif  /* __GSPELL_CHECKER_DIALOG_H__ */
-
-/* ex:set ts=8 noet: */
+#endif  /* GSPELL_CHECKER_DIALOG_H */
