@@ -28,10 +28,6 @@
 #include <string.h>
 #include "gspell-utils.h"
 
-#ifdef OS_OSX
-#include "gspell-osx.h"
-#endif
-
 /**
  * SECTION:checker
  * @Short_description: Spell checker
@@ -663,5 +659,3 @@ gspell_checker_get_enchant_dict (GspellChecker *checker)
 	priv = gspell_checker_get_instance_private (checker);
 	return priv->dict;
 }
-
-/* ex:set ts=8 noet: */
